==> 0.5.6.tar.gz: lib/widgets/dialog/dialog_supper_admin.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wowit/common.dart';
import 'package:wowit/controllers/base_controller.dart';
import 'package:wowit/widgets/common_widget.dart';
import 'package:wowit/widgets/log_widget/log_widget.dart';

class DiaLogSupperAdmin extends StatelessWidget {
  final BaseController? controller;
  const DiaLogSupperAdmin({Key? key, this.controller}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Dialog(
      backgroundColor: Colors.white,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(10),
      ),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          _title(context),
          _button(
              text: Common.showKeyMessage
                  ? 'Hiển thị bình thường'
                  : 'Hiển thị message ID',
              onTap: () {
                Common.showKeyMessage = !Common.showKeyMessage;
                controller!.update();
                Get.back();
              }),
          const Divider(),
          _button(
              text: 'Danh sách message',
              onTap: () {
                Get.back();
                Get.to(
                  () => MessageListScreen(
                    data: controller!.messageIdBackUp,
                  ),
                );
              }),
          const Divider(),
          _button(
              text: 'Hiển thị log',
              onTap: () {
                Get.back();
                Get.to(() => const LogWidget());
              }),
          const SizedBox(
            height: 8,
          )
        ],
      ),
    );
  }

  Widget _title(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.symmetric(vertical: 16),
      child: Text(
        'Con mắt thần thánh',
        textAlign: TextAlign.center,
        style: TextStyle(fontWeight: FontWeight.w600, fontSize: 18),
      ),
    );
  }

  Widget _button({String? text, Function()? onTap}) {
    return InkWell(
      onTap: () {
        if (onTap != null) {
          onTap();
        }
      },
      child: Container(
        width: Get.width,
        padding: const EdgeInsets.symmetric(vertical: 8),
        child: Text(
          text ?? '',
          textAlign: TextAlign.center,
          style: const TextStyle(
            color: Colors.blueAccent,
          ),
        ),
      ),
    );
  }
}

==> 0.5.13.tar.gz: lib/widgets/dialog/dialog_supper_admin.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wowit/common.dart';
import 'package:wowit/widgets/common_widget.dart';
import 'package:wowit/widgets/log_widget/log_widget.dart';

class DiaLogSupperAdmin extends StatelessWidget {
  // final BaseController? controller;
  final String currentRoute;
  const DiaLogSupperAdmin({Key? key, required this.currentRoute}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Dialog(
      backgroundColor: Colors.white,
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(10),
      ),
      child: Column(
        mainAxisSize: MainAxisSize.min,
        crossAxisAlignment: CrossAxisAlignment.center,
        children: [
          _title(context),
          _button(
              text: Common.showKeyMessage
                  ? 'Hiển thị bình thường'
                  : 'Hiển thị message ID',
              onTap: () {
                Common.showKeyMessage = !Common.showKeyMessage;
                // controller!.update();
                Get.forceAppUpdate();
                Get.back();
              }),
          const Divider(),
          _button(
              text: 'Danh sách message',
              onTap: () {
                Get.back();
                Get.to(
                  () => MessageListScreen(
                    // data: controller!.messageIdBackUp,
                    currentRoute: currentRoute,
                  ),
                );
              }),
          const Divider(),
          _button(
              text: 'Hiển thị log',
              onTap: () {
                Get.back();
                Get.to(() => const LogWidget());
              }),
          const SizedBox(
            height: 8,
          )
        ],
      ),
    );
  }

  Widget _title(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.symmetric(vertical: 16),
      child: Text(
        'Con mắt thần thánh',
        textAlign: TextAlign.center,
        style: TextStyle(fontWeight: FontWeight.w600, fontSize: 18),
      ),
    );
  }

  Widget _button({String? text, Function()? onTap}) {
    return InkWell(
      onTap: () {
        if (onTap != null) {
          onTap();
        }
      },
      child: Container(
        width: Get.width,
        padding: const EdgeInsets.symmetric(vertical: 8),
        child: Text(
          text ?? '',
          textAlign: TextAlign.center,
          style: const TextStyle(
            color: Colors.blueAccent,
          ),
        ),
      ),
    );
  }
}
